/**
* Klasse für einen Pfeil
*/
function Pfeil(
    x1,
    y1,
    x2,
    y2
) {
    this.x1 = x1;
    this.x2 = x2;
    this.y1 = y1;
    this.y2 = y2;
    this.draw();
}

// Ursprung des Koordinatensystems in lokalen Einheiten
Pfeil.ORIGIN_X = 2;
Pfeil.ORIGIN_Y = 2;

// Ankerpunkt
Pfeil.prototype.x1 = 0;
Pfeil.prototype.y1 = 0;

// Punkt der Pfeilspitze
Pfeil.prototype.x2 = 0;
Pfeil.prototype.y2 = 0;

// x-Koordinate des Vektors
Object.defineProperty(Pfeil.prototype, 'deltaX', {
    enumerable: true,
    get() { return this.x2 - this.x1; }
});

// y-Koordinate des Vektors
Object.defineProperty(Pfeil.prototype, 'deltaY', {
    enumerable: true,
    get() { return this.y2 - this.y1; }
});

// Länge des Vektors
Object.defineProperty(Pfeil.prototype, 'abs', {
    enumerable: true,
    get() {
        const x = this.deltaX;
        const y = this.deltaY;
        return Math.sqrt(x*x + y*y);
    }
});

// Richtung des Vektors (Bogenmaß zur x-Achse
Object.defineProperty(Pfeil.prototype, 'angle', {
    enumerable: true,
    get() { return Math.atan2(this.deltaY, this.deltaX); }
});

/**
* Verlauf des Pfeils zeichnen
* @return undefined
*/
Pfeil.prototype.draw = function() {
    var d = 'M' + (this.x1 + Pfeil.ORIGIN_X) + ',' + (this.y1 + Pfeil.ORIGIN_Y) + 'L';
    d += (this.x2 + Pfeil.ORIGIN_X) + ',' + (this.y2 + Pfeil.ORIGIN_Y);
    this.node = document.createElementNS('http://www.w3.org/2000/svg', 'path');
    this.node.setAttribute('d', d);
    this.node.setAttribute('style', 'marker-end:url(#Pfeilspitze)');
    document.getElementById('layer1').appendChild(this.node);
}

/**
* Pfeil aus SVG entfernen
* @return undefined
*/
Pfeil.prototype.remove = function() {
    if (this.node.parentNode)
        this.node.parentNode.removeChild(this.node);
}
